package com.yidianling.dynamic.topic.topicDetail;

import com.ydl.ydlcommon.mvp.base.IView;
import com.yidianling.dynamic.model.Focus;
import com.yidianling.dynamic.model.TopicDetailBean;

/**
 * Created by Jim on 2017/12/27 0027.
 */

public interface TopicDetailView extends IView {
    void showToast(String msg);
    void showTopicHeadDetail(TopicDetailBean topicDetail);
    void showLoadingView(String message);
    void hideLoadingView();
    void hideProgressView();
    void showFocusResult(Focus result);
    void showFocusError(Throwable throwable);
    void showErrorView();
}
